# flake8: noqa

"""
    XBIM Flex API v2

    This is the XBIM Flex Swagger service where you can explore the REST API for the platform.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: info@xbim.net
    Generated by: https://openapi-generator.tech
"""


__version__ = "2.0.4"

# import ApiClient
from xbim_flex.aim.api_client import ApiClient

# import Configuration
from xbim_flex.aim.configuration import Configuration

# import exceptions
from xbim_flex.aim.exceptions import OpenApiException
from xbim_flex.aim.exceptions import ApiAttributeError
from xbim_flex.aim.exceptions import ApiTypeError
from xbim_flex.aim.exceptions import ApiValueError
from xbim_flex.aim.exceptions import ApiKeyError
from xbim_flex.aim.exceptions import ApiException



# flake8: noqa

"""
    Xbim Flex Identity API 2.0

    Global management and user services for xbim Flex Tenants  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: info@xbim.net
    Generated by: https://openapi-generator.tech
"""


__version__ = "2.0.4"

# import ApiClient
from xbim_flex.identity.api_client import ApiClient

# import Configuration
from xbim_flex.identity.configuration import Configuration

# import exceptions
from xbim_flex.identity.exceptions import OpenApiException
from xbim_flex.identity.exceptions import ApiAttributeError
from xbim_flex.identity.exceptions import ApiTypeError
from xbim_flex.identity.exceptions import ApiValueError
from xbim_flex.identity.exceptions import ApiKeyError
from xbim_flex.identity.exceptions import ApiException
